@@ -2,7 +2,7 @@
  * BRLTTY - A background process providing access to the console screen (when in
  *          text mode) for a blind person using a refreshable braille display.
  *
- * Copyright (C) 1995-2010 by The BRLTTY Developers.
+ * Copyright (C) 1995-2012 by The BRLTTY Developers.
  *
  * BRLTTY comes with ABSOLUTELY NO WARRANTY.
  *
@@ -57,9 +57,9 @@ extern "C" {
 #define BRL_CMD_PRPROMPT (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_PRPROMPT)
 /** go down to next command prompt */
 #define BRL_CMD_NXPROMPT (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_NXPROMPT)
-/** search backward for cut text */
+/** search backward for clipboard text */
 #define BRL_CMD_PRSEARCH (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_PRSEARCH)
-/** search forward for cut text */
+/** search forward for clipboard text */
 #define BRL_CMD_NXSEARCH (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_NXSEARCH)
 /** go left one character */
 #define BRL_CMD_CHRLT (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_CHRLT)
@@ -89,37 +89,37 @@ extern "C" {
 #define BRL_CMD_RETURN (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_RETURN)
 /** freeze/unfreeze screen image */
 #define BRL_CMD_FREEZE (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_FREEZE)
-/** toggle display mode attributes/text */
+/** set display mode attributes/text */
 #define BRL_CMD_DISPMD (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_DISPMD)
-/** toggle text style 6-dot/8-dot */
+/** set text style 6-dot/8-dot */
 #define BRL_CMD_SIXDOTS (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_SIXDOTS)
-/** toggle sliding window on/off */
+/** set sliding window on/off */
 #define BRL_CMD_SLIDEWIN (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_SLIDEWIN)
-/** toggle skipping of lines with identical content on/off */
+/** set skipping of lines with identical content on/off */
 #define BRL_CMD_SKPIDLNS (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_SKPIDLNS)
-/** toggle skipping of blank windows on/off */
+/** set skipping of blank windows on/off */
 #define BRL_CMD_SKPBLNKWINS (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_SKPBLNKWINS)
-/** toggle cursor visibility on/off */
+/** set cursor visibility on/off */
 #define BRL_CMD_CSRVIS (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_CSRVIS)
-/** toggle hidden cursor on/off */
+/** set hidden cursor on/off */
 #define BRL_CMD_CSRHIDE (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_CSRHIDE)
-/** toggle cursor tracking on/off */
+/** set cursor tracking on/off */
 #define BRL_CMD_CSRTRK (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_CSRTRK)
-/** toggle cursor style block/underline */
+/** set cursor style block/underline */
 #define BRL_CMD_CSRSIZE (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_CSRSIZE)
-/** toggle cursor blinking on/off */
+/** set cursor blinking on/off */
 #define BRL_CMD_CSRBLINK (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_CSRBLINK)
-/** toggle attribute underlining on/off */
+/** set attribute underlining on/off */
 #define BRL_CMD_ATTRVIS (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_ATTRVIS)
-/** toggle attribute blinking on/off */
+/** set attribute blinking on/off */
 #define BRL_CMD_ATTRBLINK (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_ATTRBLINK)
-/** toggle capital letter blinking on/off */
+/** set capital letter blinking on/off */
 #define BRL_CMD_CAPBLINK (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_CAPBLINK)
-/** toggle alert tunes on/off */
+/** set alert tunes on/off */
 #define BRL_CMD_TUNES (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_TUNES)
-/** toggle autorepeat on/off */
+/** set autorepeat on/off */
 #define BRL_CMD_AUTOREPEAT (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_AUTOREPEAT)
-/** toggle autospeak on/off */
+/** set autospeak on/off */
 #define BRL_CMD_AUTOSPEAK (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_AUTOSPEAK)
 /** enter/leave help display */
 #define BRL_CMD_HELP (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_HELP)
@@ -169,7 +169,7 @@ extern "C" {
 #define BRL_CMD_SWITCHVT_NEXT (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_SWITCHVT_NEXT)
 /** bring cursor to line */
 #define BRL_CMD_CSRJMP_VERT (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_CSRJMP_VERT)
-/** insert cut text at cursor */
+/** insert clipboard text at cursor */
 #define BRL_CMD_PASTE (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_PASTE)
 /** restart braille driver */
 #define BRL_CMD_RESTARTBRL (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_RESTARTBRL)
@@ -177,6 +177,66 @@ extern "C" {
 #define BRL_CMD_RESTARTSPEECH (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_RESTARTSPEECH)
 /** braille display temporarily unavailable */
 #define BRL_CMD_OFFLINE (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_OFFLINE)
+/** add shift modifier to next typed character or emulated key */
+#define BRL_CMD_SHIFT (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_SHIFT)
+/** add upper modifier to next typed character or emulated key */
+#define BRL_CMD_UPPER (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_UPPER)
+/** add control modifier to next typed character or emulated key */
+#define BRL_CMD_CONTROL (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_CONTROL)
+/** add meta modifier to next typed character or emulated key */
+#define BRL_CMD_META (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_META)
+/** show the current date and time */
+#define BRL_CMD_TIME (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_TIME)
+/** go to previous menu level */
+#define BRL_CMD_MENU_PREV_LEVEL (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_MENU_PREV_LEVEL)
+/** set autospeak selected line on/off */
+#define BRL_CMD_ASPK_SEL_LINE (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_ASPK_SEL_LINE)
+/** set autospeak selected character on/off */
+#define BRL_CMD_ASPK_SEL_CHAR (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_ASPK_SEL_CHAR)
+/** set autospeak inserted characters on/off */
+#define BRL_CMD_ASPK_INS_CHARS (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_ASPK_INS_CHARS)
+/** set autospeak deleted characters on/off */
+#define BRL_CMD_ASPK_DEL_CHARS (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_ASPK_DEL_CHARS)
+/** set autospeak replaced characters on/off */
+#define BRL_CMD_ASPK_REP_CHARS (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_ASPK_REP_CHARS)
+/** set autospeak completed words on/off */
+#define BRL_CMD_ASPK_CMP_WORDS (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_ASPK_CMP_WORDS)
+/** speak current character */
+#define BRL_CMD_SPEAK_CURR_CHAR (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_SPEAK_CURR_CHAR)
+/** go to and speak previous character */
+#define BRL_CMD_SPEAK_PREV_CHAR (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_SPEAK_PREV_CHAR)
+/** go to and speak next character */
+#define BRL_CMD_SPEAK_NEXT_CHAR (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_SPEAK_NEXT_CHAR)
+/** speak current word */
+#define BRL_CMD_SPEAK_CURR_WORD (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_SPEAK_CURR_WORD)
+/** go to and speak previous word */
+#define BRL_CMD_SPEAK_PREV_WORD (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_SPEAK_PREV_WORD)
+/** go to and speak next word */
+#define BRL_CMD_SPEAK_NEXT_WORD (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_SPEAK_NEXT_WORD)
+/** speak current line */
+#define BRL_CMD_SPEAK_CURR_LINE (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_SPEAK_CURR_LINE)
+/** go to and speak previous line */
+#define BRL_CMD_SPEAK_PREV_LINE (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_SPEAK_PREV_LINE)
+/** go to and speak next line */
+#define BRL_CMD_SPEAK_NEXT_LINE (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_SPEAK_NEXT_LINE)
+/** go to and speak first non-blank character on line */
+#define BRL_CMD_SPEAK_FRST_CHAR (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_SPEAK_FRST_CHAR)
+/** go to and speak last non-blank character on line */
+#define BRL_CMD_SPEAK_LAST_CHAR (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_SPEAK_LAST_CHAR)
+/** go to and speak first non-blank line on screen */
+#define BRL_CMD_SPEAK_FRST_LINE (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_SPEAK_FRST_LINE)
+/** go to and speak last non-blank line on screen */
+#define BRL_CMD_SPEAK_LAST_LINE (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_SPEAK_LAST_LINE)
+/** describe current character */
+#define BRL_CMD_DESC_CURR_CHAR (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_DESC_CURR_CHAR)
+/** spell current word */
+#define BRL_CMD_SPELL_CURR_WORD (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_SPELL_CURR_WORD)
+/** bring cursor to speech location */
+#define BRL_CMD_ROUTE_CURR_LOCN (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_ROUTE_CURR_LOCN)
+/** speak speech location */
+#define BRL_CMD_SPEAK_CURR_LOCN (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_SPEAK_CURR_LOCN)
+/** set speech location visibility on/off */
+#define BRL_CMD_SHOW_CURR_LOCN (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_SHOW_CURR_LOCN)
 /** enable feature */
 #define BRL_FLG_TOGGLE_ON BRLAPI_KEY_FLG_TOGGLE_ON
 /** disable feature */
@@ -193,13 +253,21 @@ extern "C" {
 #define BRL_FLG_REPEAT_MASK BRLAPI_KEY_FLG_REPEAT_MASK
 /** bring cursor to character */
 #define BRL_BLK_ROUTE (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_ROUTE)
-/** start new cut buffer at character */
+/** start new clipboard at character */
+#define BRL_BLK_CLIP_NEW (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_CLIP_NEW)
+/** deprecated definition of CLIP_NEW - start new clipboard at character */
 #define BRL_BLK_CUTBEGIN (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_CUTBEGIN)
-/** append to existing cut buffer from character */
+/** append to clipboard from character */
+#define BRL_BLK_CLIP_ADD (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_CLIP_ADD)
+/** deprecated definition of CLIP_ADD - append to clipboard from character */
 #define BRL_BLK_CUTAPPEND (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_CUTAPPEND)
-/** rectangular cut to character */
+/** rectangular copy to character */
+#define BRL_BLK_COPY_RECT (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_COPY_RECT)
+/** deprecated definition of COPY_RECT - rectangular copy to character */
 #define BRL_BLK_CUTRECT (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_CUTRECT)
-/** linear cut to character */
+/** linear copy to character */
+#define BRL_BLK_COPY_LINE (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_COPY_LINE)
+/** deprecated definition of COPY_LINE - linear copy to character */
 #define BRL_BLK_CUTLINE (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_CUTLINE)
 /** switch to virtual terminal */
 #define BRL_BLK_SWITCHVT (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_SWITCHVT)
@@ -225,11 +293,17 @@ extern "C" {
 #define BRL_BLK_PRDIFCHAR (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_PRDIFCHAR)
 /** go down to nearest line with different character */
 #define BRL_BLK_NXDIFCHAR (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_NXDIFCHAR)
-/** copy characters to cut buffer */
+/** copy characters to clipboard */
+#define BRL_BLK_CLIP_COPY (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_CLIP_COPY)
+/** deprecated definition of CLIP_COPY - copy characters to clipboard */
 #define BRL_BLK_COPYCHARS (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_COPYCHARS)
-/** append characters to cut buffer */
+/** append characters to clipboard */
+#define BRL_BLK_CLIP_APPEND (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_CLIP_APPEND)
+/** deprecated definition of CLIP_APPEND - append characters to clipboard */
 #define BRL_BLK_APNDCHARS (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_APNDCHARS)
-/** input keyboard key */
+/** put random password into clipboard */
+#define BRL_BLK_PWGEN (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_PWGEN)
+/** emulate special key */
 #define BRL_KEY_PASSKEY (BRLAPI_KEY_TYPE_SYM | 0XFF00)
 /** enter key */
 #define BRL_KEY_ENTER (BRLAPI_KEY_SYM_LINEFEED & 0XFF)
@@ -261,9 +335,9 @@ extern "C" {
 #define BRL_KEY_DELETE (BRLAPI_KEY_SYM_DELETE & 0XFF)
 /** function key */
 #define BRL_KEY_FUNCTION (BRLAPI_KEY_SYM_FUNCTION & 0XFF)
-/** input unicode character */
+/** type unicode character */
 #define BRL_KEY_PASSCHAR (BRLAPI_KEY_TYPE_SYM | 0X0000)
-/** input braille character */
+/** type braille character */
 #define BRL_BLK_PASSDOTS (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_PASSDOTS)
 /** shift key pressed */
 #define BRL_FLG_CHAR_SHIFT BRLAPI_KEY_FLG_SHIFT
@@ -291,11 +365,11 @@ extern "C" {
 #define BRL_DOT8 BRLAPI_DOT8
 /** space key pressed */
 #define BRL_DOTC BRLAPI_DOTC
-/** input AT (set 2) keyboard scan code */
+/** AT (set 2) keyboard scan code */
 #define BRL_BLK_PASSAT (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_PASSAT)
-/** input XT (set 1) keyboard scan code */
+/** XT (set 1) keyboard scan code */
 #define BRL_BLK_PASSXT (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_PASSXT)
-/** input PS/2 (set 3) keyboard scan code */
+/** PS/2 (set 3) keyboard scan code */
 #define BRL_BLK_PASSPS2 (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_PASSPS2)
 /** it is a release scan code */
 #define BRL_FLG_KBD_RELEASE BRLAPI_KEY_FLG_KBD_RELEASE
